Documentation
¶
Overview ¶
Package instrumentation defines behaviors to instrument the CRDT stack.
Index ¶
- type DeleteInstrumentation
- type InsertInstrumentation
- type Instrumentation
- type NopInstrumentation
- func (i NopInstrumentation) DeleteCall()
- func (i NopInstrumentation) DeleteCallDuration(time.Duration)
- func (i NopInstrumentation) DeleteQuorumFailure()
- func (i NopInstrumentation) DeleteRecordCount(int)
- func (i NopInstrumentation) DeleteRecordDuration(time.Duration)
- func (i NopInstrumentation) InsertCall()
- func (i NopInstrumentation) InsertCallDuration(time.Duration)
- func (i NopInstrumentation) InsertQuorumFailure()
- func (i NopInstrumentation) InsertRecordCount(int)
- func (i NopInstrumentation) InsertRecordDuration(time.Duration)
- func (i NopInstrumentation) RepairCall()
- func (i NopInstrumentation) RepairDiscarded(int)
- func (i NopInstrumentation) RepairRequest(int)
- func (i NopInstrumentation) RepairWriteFailure(int)
- func (i NopInstrumentation) RepairWriteSuccess(int)
- func (i NopInstrumentation) SelectBlockingDuration(time.Duration)
- func (i NopInstrumentation) SelectCall()
- func (i NopInstrumentation) SelectDuration(time.Duration)
- func (i NopInstrumentation) SelectFirstResponseDuration(time.Duration)
- func (i NopInstrumentation) SelectKeys(int)
- func (i NopInstrumentation) SelectOverheadDuration(time.Duration)
- func (i NopInstrumentation) SelectPartialError()
- func (i NopInstrumentation) SelectRepairNeeded(int)
- func (i NopInstrumentation) SelectRetrieved(int)
- func (i NopInstrumentation) SelectReturned(int)
- func (i NopInstrumentation) SelectSendAllPromotion()
- func (i NopInstrumentation) SelectSendTo(int)
- func (i NopInstrumentation) WalkKeys(int)
- type RepairInstrumentation
- type SelectInstrumentation
- type WalkInstrumentation
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DeleteInstrumentation ¶
type DeleteInstrumentation interface {
DeleteCall() // called for every invocation of Delete
DeleteRecordCount(int) // +N, where N is how many records were provided to the Delete call
DeleteCallDuration(time.Duration) // time spent per call
DeleteRecordDuration(time.Duration) // time spent per record (average)
DeleteQuorumFailure() // called if the Delete failed due to lack of quorum
}
DeleteInstrumentation describes metrics for the Delete path.
type InsertInstrumentation ¶
type InsertInstrumentation interface {
InsertCall() // called for every invocation of Insert
InsertRecordCount(int) // +N, where N is how many records were provided to the Insert call
InsertCallDuration(time.Duration) // time spent per call
InsertRecordDuration(time.Duration) // time spent per record (average)
InsertQuorumFailure() // called if the Insert failed due to lack of quorum
}
InsertInstrumentation describes metrics for the Insert path.
type Instrumentation ¶
type Instrumentation interface {
InsertInstrumentation
SelectInstrumentation
DeleteInstrumentation
RepairInstrumentation
WalkInstrumentation
}
Instrumentation describes the behaviors needed by the CRDT stack to report metrics about its performance.
type NopInstrumentation ¶
type NopInstrumentation struct{}
NopInstrumentation satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) DeleteCall ¶
func (i NopInstrumentation) DeleteCall()
DeleteCall satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) DeleteCallDuration ¶
func (i NopInstrumentation) DeleteCallDuration(time.Duration)
DeleteCallDuration satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) DeleteQuorumFailure ¶
func (i NopInstrumentation) DeleteQuorumFailure()
DeleteQuorumFailure satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) DeleteRecordCount ¶
func (i NopInstrumentation) DeleteRecordCount(int)
DeleteRecordCount satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) DeleteRecordDuration ¶
func (i NopInstrumentation) DeleteRecordDuration(time.Duration)
DeleteRecordDuration satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) InsertCall ¶
func (i NopInstrumentation) InsertCall()
InsertCall satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) InsertCallDuration ¶
func (i NopInstrumentation) InsertCallDuration(time.Duration)
InsertCallDuration satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) InsertQuorumFailure ¶
func (i NopInstrumentation) InsertQuorumFailure()
InsertQuorumFailure satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) InsertRecordCount ¶
func (i NopInstrumentation) InsertRecordCount(int)
InsertRecordCount satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) InsertRecordDuration ¶
func (i NopInstrumentation) InsertRecordDuration(time.Duration)
InsertRecordDuration satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) RepairCall ¶
func (i NopInstrumentation) RepairCall()
RepairCall satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) RepairDiscarded ¶
func (i NopInstrumentation) RepairDiscarded(int)
RepairDiscarded satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) RepairRequest ¶ added in v0.0.2
func (i NopInstrumentation) RepairRequest(int)
RepairRequest satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) RepairWriteFailure ¶
func (i NopInstrumentation) RepairWriteFailure(int)
RepairWriteFailure satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) RepairWriteSuccess ¶
func (i NopInstrumentation) RepairWriteSuccess(int)
RepairWriteSuccess satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectBlockingDuration ¶
func (i NopInstrumentation) SelectBlockingDuration(time.Duration)
SelectBlockingDuration satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectCall ¶
func (i NopInstrumentation) SelectCall()
SelectCall satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectDuration ¶
func (i NopInstrumentation) SelectDuration(time.Duration)
SelectDuration satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectFirstResponseDuration ¶
func (i NopInstrumentation) SelectFirstResponseDuration(time.Duration)
SelectFirstResponseDuration satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectKeys ¶ added in v0.0.2
func (i NopInstrumentation) SelectKeys(int)
SelectKeys satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectOverheadDuration ¶
func (i NopInstrumentation) SelectOverheadDuration(time.Duration)
SelectOverheadDuration satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectPartialError ¶
func (i NopInstrumentation) SelectPartialError()
SelectPartialError satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectRepairNeeded ¶ added in v0.0.2
func (i NopInstrumentation) SelectRepairNeeded(int)
SelectRepairNeeded satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectRetrieved ¶ added in v0.0.2
func (i NopInstrumentation) SelectRetrieved(int)
SelectRetrieved satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectReturned ¶ added in v0.0.2
func (i NopInstrumentation) SelectReturned(int)
SelectReturned satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectSendAllPromotion ¶
func (i NopInstrumentation) SelectSendAllPromotion()
SelectSendAllPromotion satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) SelectSendTo ¶ added in v0.0.2
func (i NopInstrumentation) SelectSendTo(int)
SelectSendTo satisfies the Instrumentation interface but does no work.
func (NopInstrumentation) WalkKeys ¶ added in v0.0.2
func (i NopInstrumentation) WalkKeys(int)
WalkKeys satisfies the Instrumentation interface but does no work.
type RepairInstrumentation ¶
type RepairInstrumentation interface {
RepairCall() // called for every requested repair
RepairRequest(int) // +N, where N is the total number of keyMembers for which repair was requested
RepairDiscarded(int) // +N, where N is keyMembers requested to repair but discarded due to e.g. rate limits
RepairWriteSuccess(int) // +N, where N is keyMembers successfully written to a cluster as a result of a repair
RepairWriteFailure(int) // +N, where N is keyMembers unsuccessfully written to a cluster as a result of a repair
}
RepairInstrumentation describes metrics for Repairs.
type SelectInstrumentation ¶
type SelectInstrumentation interface {
SelectCall() // called for every invocation of Select
SelectKeys(int) // how many keys were requested
SelectSendTo(int) // how many clusters the read strategy sent the read to
SelectFirstResponseDuration(time.Duration) // how long until we got the first element
SelectPartialError() // called when an individual key gave an error from the cluster
SelectBlockingDuration(time.Duration) // time spent waiting for everything
SelectOverheadDuration(time.Duration) // time spent not waiting
SelectDuration(time.Duration) // overall time performing this read (blocking + overhead)
SelectSendAllPromotion() // called when the read strategy promotes a "SendOne" to a "SendAll" because of missing results
SelectRetrieved(int) // total number of KeyScoreMembers retrieved from the backing store
SelectReturned(int) // total number of KeyScoreMembers returned to the caller
SelectRepairNeeded(int) // +N, where N is every keyMember detected in a difference set (prior to entering repair strategy)
}
SelectInstrumentation describes metrics for the Select path.
type WalkInstrumentation ¶ added in v0.0.2
type WalkInstrumentation interface {
WalkKeys(int) // +N, where N is the number of keys received from a Scanner and sent for Select
}
WalkInstrumentation describes metrics for walkers.